ReelTextProgress class
Handle returned by ReelTextController.startProgress.
Keep the handle for the async operation that owns the in-progress label and resolve it with complete or fail. Calling any method after the handle is no longer active is a no-op.
Properties
Methods
-
cancel(
{String? text, ReelTextOptions? options}) → void -
Stops the progress loop. When
textis provided, it is emitted as the next resting label. -
complete(
String text, {ReelTextOptions? options}) → void -
Stops the progress loop and rolls to
text. -
fail(
String text, {ReelTextOptions? options}) → void -
Stops the progress loop and rolls to an error
text. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited